# Welcome to Python Library "useragentxxc"
**The latest version is 1.1.0**
Latest function: random generation of user agent
## Example
**PC**
```python
#The default value of type is' all ', which can be specified as' Firefox', 'chrome' and 'Safari'
from useragent-xxc import PC
PC.random()
#out:Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.77 Safari/537.36
```

##About version number
** Specified version number format is X.Y.Z**
>X changes only when the module needs to be refactored.
Y adjusts when a method property is added or modified.
Z add a source address every time user agents data is updated

##About author
**1.The source code is here:[Source address](https://github.com/clearDreamXXC/user-agent)
2.If you have any good suggestions, please email me at 1586616064@qq.com
3.The author's English is relatively poor, so some of the content may not be suitable for reading.**